;;-----------------------------LICENSE NOTICE------------------------------------
;; (C) Gallegux+z80@gmail.com
;;
;;  This program is free software: you can redistribute it and/or modify
;;  it under the terms of the GNU Lesser General Public License as published by
;;  the Free Software Foundation, either version 3 of the License, or
;;  (at your option) any later version.
;;
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU Lesser General Public License for more details.
;;
;;  You should have received a copy of the GNU Lesser General Public License
;;  along with this program.  If not, see <http://www.gnu.org/licenses/>.
;;-------------------------------------------------------------------------------



macro ProbarVentana _v
	VentanaRender _v
	EsperarSegundos 1
	call esperar_tecla
	call ventana_restaurar
endm



pausa:
	
	ld hl, ventana_pausa
	call ventana_render
	EsperarSegundos 1

_juego_seguir_pausa
	call esperar_tecla
	
	ld de, K_Esc
	call comparar_bc_de 
	jr nz, _juego_fin_pausa
	
	call stop_music
	pop af 
	pop af 
	pop af 
	pop af 
	ret 
_juego_fin_pausa
	
	call ventana_restaurar
	RET





is_objetivo_conseguido:
	ld a, (pantalla_mapa_yx)
	cp PANTALLA_INICIAL_YX
	ret nz
	
	ld hl, array_objetos_mochila-1
	ld bc, NUM_OBJETOS_MOCHILA*256   
_ioc_loop
	inc hl
	ld a, (hl)

	cp OBJ_CUERDA
	jr z, _ioc_esta
	cp OBJ_TELA
	jr z, _ioc_esta
	cp OBJ_HACHA
	jr z, _ioc_esta
	cp OBJ_MAPA
	jr z, _ioc_esta
_ioc_sig
	djnz _ioc_loop
	ld a, 4
	cp c
	ret

_ioc_esta
	inc c
	jr _ioc_sig



macro DatosGameOver _ventana, _musica, _sfx, _parar_musica
	ld hl, _ventana
	ld bc, _musica
	ld a, _sfx
	ld d, _parar_musica
endm



objetivo_conseguido:
	DatosGameOver ventana_objetivo_conseguido, musica_menu_compressed, 0, 0
	call game_over
	RET




juego_colision_canibal:
	call get_modo_canibal
	ret nz   

	ld a, OBJ_SOBRE
	call mochila_remove_objeto
	jr z, _coli_sobre
		DatosGameOver ventana_game_over_atrapado, musica_silencio_compressed, SFX_ATRAPADO, 1
		call game_over
		pop bc
		ret
_coli_sobre
	
	ld a, MODO_CANIBAL_TONTO
	ld (modo_canibal), a
	ld l, SFX_USAR_SOBRE
	call play_sfx
	call get_sprites_canibal_billete
	ret



juego_colision_serpiente:
	ld a, OBJ_ANTIDOTO
	call mochila_remove_objeto
	jr z, _coli_antidoto
		ld l, SFX_SERPIENTE
		call play_sfx
		call vida_picadura_serpiente
		call gamer_over_check_picadura
		ret nz 
		
		
		call juego_render_personajes_1_frame
		DatosGameOver ventana_game_over_serpiente, musica_silencio_compressed, SFX_ATRAPADO, 1
		call game_over
		pop bc
		ret
		
_coli_antidoto
	ld l, SFX_USAR_ANTIDOTO
	call play_sfx
	ld_a MODO_NO_PICAR
	ld (modo_serpiente), a
	ret




gamer_over_check_picadura:
	ld a, (nivel_agua)
	or a
	ret z
	
	ld a, (nivel_energia)
	or a
	
	ret



juego_sin_energia:
	DatosGameOver ventana_game_over_sin_energia, musica_silencio_compressed, SFX_ATRAPADO, 1
	call game_over
	ret
	

juego_sin_agua:
	DatosGameOver ventana_game_over_sin_agua, musica_silencio_compressed, SFX_ATRAPADO, 1
	call game_over
	ret




game_over:
	ld (__go_sfx), a
	ld (__go_musica), bc
	ld (__go_ventana), hl
	ld a, d
	ld (__go_parar_musica), a

	call fade_out_musica
	call stop_music	

	ld hl, #0000
	__go_musica equ $-2
	ld de, musica
	call dzx0
	call play_music
			
	ld a, 0
	call cpct_akp_setFadeVolume_asm
	
	ld a, #00
	__go_sfx equ $-1
	or a 
	jr z, _go_nosfx
		ld l, a
		call play_sfx

	_go_nosfx
	EsperarSegundos 3
	ld hl, #0000
	__go_ventana equ $-2
	call ventana_render
	call esperar_tecla
	
	ld a, #00
	__go_parar_musica equ $-1
	or a
	jr z, _go_no_parar
		call stop_music
	_go_no_parar
	RET




juego_render_personajes_1_frame:
	call waitVSYNC
	call cambiar_pagina_visible
	call juego_render_personajes
	call waitVSYNC
	call cambiar_pagina_visible
	ret
		



fade_out_musica:
	ld h, 0
	
_fom_loop
	inc h
	ld a, h
	call cpct_akp_setFadeVolume_asm
	halt
	halt
	call waitVSYNC
	
	ld a, h
	cp 15
	jr nz, _fom_loop
	
	call stop_music
	ld a, 0
	call cpct_akp_setFadeVolume_asm
	
	ret
	
	

